@@ -20,7 +20,7 @@ class RegionEstimator(object):
             Args:
                 sensors: list of sensors as pandas.DataFrame
                     Required columns:
-                        'sensor_id' (str or int) Unique identifier (will be converted to string)
+                        'sensor_id' (str or int) Unique identifier (will be converted to str)
                         'latitude' (float): latitude of sensor location
                         'longitude' (float): longitude of sensor location
                         'name' (string (Optional): Name of sensor
@@ -32,8 +32,9 @@ class RegionEstimator(object):
 
                 actuals: list of sensor values as pandas.DataFrame
                     Required columns:
-                        'timestamp' (string): timestamp of actual reading
-                        'sensor_id': ID of sensor which took actual reading - must match an index value in sensors
+                        'timestamp' (str): timestamp of actual reading
+                        'sensor_id': (str or int) ID of sensor which took actual reading - must match an index
+                            value in sensors. (will be converted to str)
                         [one or more value columns] (float):    value of actual measurement readings.
                                                                 each column name is the name of the measurement
                                                                 e.g. 'NO2'
@@ -80,10 +81,6 @@ class RegionEstimator(object):
             "Each sensor ID must match a sensor_id in sensors. Error sensor IDs: " + str(error_sensors)
 
 
-        ### Convert sensors to geo dataframe
-        #sensors.reset_index(inplace=True)
-        #sensors['sensor_id'] = sensors['sensor_id'].astype(str)
-        #sensors.set_index('sensor_id', inplace=True)
         sensors.index = sensors.index.map(str)
         try:
             gdf_sensors = gpd.GeoDataFrame(data=sensors,
@@ -103,6 +100,8 @@ class RegionEstimator(object):
         cols.insert(0, cols.pop(cols.index('sensor_id')))
         cols.insert(0, cols.pop(cols.index('timestamp')))
 
+        actuals['sensor_id'] = actuals['sensor_id'].astype(str)
+
         self.sensors = gdf_sensors
         self.regions = gdf_regions
         self.actuals = actuals
